@@ -13,6 +13,8 @@ parametrize = pytest.mark.parametrize
 
 today = dt.date.today()
 
+SomeNamedTuple = namedtuple("SomeNamedTuple", ["a", "b"])
+
 
 @parametrize(
     "case,expected",
@@ -216,6 +218,24 @@ def test_invoke(case, expected):
     assert _.invoke(*case) == expected
 
 
+@parametrize(
+    "case",
+    [
+        ({}, "__globals__"),
+        ({}, "__builtins__"),
+        ({}, "a.__globals__.b"),
+        ({}, "a.__builtins__.b"),
+        ([], "__globals__"),
+        ([], "__builtins__"),
+        ([], "a.__globals__.b"),
+        ([], "a.__builtins__.b"),
+    ],
+)
+def test_invoke__raises_for_objects_when_path_restricted(case):
+    with pytest.raises(KeyError, match="access to restricted key"):
+        _.invoke(*case)
+
+
 @parametrize(
     "case,expected",
     [
@@ -348,7 +368,9 @@ def test_for_in_right(case, expected):
         (({"one": ["two", {"three": [4, 5]}]}, "one.1.three.1"), 5),
         ((["one", {"two": {"three": [4, 5]}}], "[1].two.three.[0]"), 4),
         ((["one", {"two": {"three": [4, [{"four": [5]}]]}}], "[1].two.three[1][0].four[0]"), 5),
+        ((["one", {"two": {"three": [4, [{"four": [5]}], 6]}}], "[1].two.three[-2][0].four[0]"), 5),
         ((range(50), "[42]"), 42),
+        ((range(50), "[-1]"), 49),
         (([[[[[[[[[[42]]]]]]]]]], "[0][0][0][0][0][0][0][0][0][0]"), 42),
         (([range(50)], "[0][42]"), 42),
         (({"a": [{"b": range(50)}]}, "a[0].b[42]"), 42),
@@ -358,9 +380,9 @@ def test_for_in_right(case, expected):
         ),
         (({"one": ["hello", "there"]}, "one.bad.hello", []), []),
         (({"one": ["hello", None]}, "one.1.hello"), None),
-        ((namedtuple("a", ["a", "b"])(1, 2), "a"), 1),
-        ((namedtuple("a", ["a", "b"])(1, 2), 0), 1),
-        ((namedtuple("a", ["a", "b"])({"c": {"d": 1}}, 2), "a.c.d"), 1),
+        ((SomeNamedTuple(1, 2), "a"), 1),
+        ((SomeNamedTuple(1, 2), 0), 1),
+        ((SomeNamedTuple({"c": {"d": 1}}, 2), "a.c.d"), 1),
         (({}, "update"), None),
         (([], "extend"), None),
         (({(1,): {(2,): 3}}, (1,)), {(2,): 3}),
@@ -385,7 +407,7 @@ def test_get__should_not_populate_defaultdict():
     "obj,path",
     [
         (helpers.Object(), "__init__.__globals__"),
-        (namedtuple("a", ["a"])(a=1), "__globals__"),
+        (SomeNamedTuple(1, 2), "__globals__"),
         (helpers.Object(subobj=helpers.Object()), "subobj.__builtins__"),
         (helpers.Object(subobj=helpers.Object()), "__builtins__"),
     ],
@@ -756,6 +778,17 @@ def test_set_(case, expected):
     assert _.set_(*case) == expected
 
 
+def test_set_on_class_works_the_same_with_string_and_list():
+    class A:
+        def __init__(self):
+            self.x = {}
+
+    a1 = A()
+    a2 = A()
+
+    assert _.set_(a1, "x.a.b", 1).x == _.set_(a2, ["x", "a", "b"], 1).x
+
+
 @parametrize(
     "case,expected",
     [
@@ -832,8 +865,8 @@ def test_to_number(case, expected):
 @parametrize(
     "case,expected",
     [
-        ({"a": 1, "b": 2, "c": 3}, [["a", 1], ["b", 2], ["c", 3]]),
-        ([1, 2, 3], [[0, 1], [1, 2], [2, 3]]),
+        ({"a": 1, "b": 2, "c": 3}, [("a", 1), ("b", 2), ("c", 3)]),
+        ([1, 2, 3], [(0, 1), (1, 2), (2, 3)]),
     ],
 )
 def test_to_pairs(case, expected):
@@ -929,3 +962,29 @@ def test_unset(obj, path, expected, new_obj):
 @parametrize("case,expected", [({"a": 1, "b": 2, "c": 3}, [1, 2, 3]), ([1, 2, 3], [1, 2, 3])])
 def test_values(case, expected):
     assert set(_.values(case)) == set(expected)
+
+
+@parametrize("case,expected", [((5, lambda x: x * 2), 10)])
+def test_apply(case, expected):
+    assert _.apply(*case) == expected
+
+
+@parametrize(
+    "case,expected",
+    [((5, lambda x: x * 2, lambda x: x == 5), 10), ((5, lambda x: x * 2, lambda x: x == 10), 5)],
+)
+def test_apply_if(case, expected):
+    assert _.apply_if(*case) == expected
+
+
+@parametrize("case,expected", [((5, lambda x: x * 2), 10), ((None, lambda x: x * 2), None)])
+def test_apply_if_not_none(case, expected):
+    assert _.apply_if_not_none(*case) == expected
+
+
+@parametrize(
+    "case,expected",
+    [((5, lambda x: x * 2, [ValueError]), 10), ((5, lambda x: x / 0, [ZeroDivisionError]), 5)],
+)
+def test_apply_catch(case, expected):
+    assert _.apply_catch(*case) == expected
