@@ -1,5 +1,4 @@
 import re
-import sys
 from urllib.parse import parse_qsl, urlsplit
 
 import pytest
@@ -28,7 +27,10 @@ parametrize = pytest.mark.parametrize
         ("Σὲ γνωρίζω ἀπὸ τὴν κόψη", "σὲΓνωρίζωἈπὸΤὴνΚόψη"),
         ("แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช", "แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช"),
         ("いろはにほへど　ちりぬるを", "いろはにほへどちりぬるを"),
-        ("나는 유리를 먹을 수 있어요. 그래도 아프지 않아요", "나는유리를먹을수있어요그래도아프지않아요"),
+        (
+            "나는 유리를 먹을 수 있어요. 그래도 아프지 않아요",
+            "나는유리를먹을수있어요그래도아프지않아요",
+        ),
         ("J'peux manger d'la vitre, ça m'fa pas mal.", "jpeuxMangerDlaVitreCaMfaPasMal"),
         ("e peux manger du verre, ça ne me fait pas mal.", "ePeuxMangerDuVerreCaNeMeFaitPasMal"),
         (8, "8"),
@@ -154,11 +156,11 @@ def test_count_substr(case, expected):
     "case,expected",
     [
         (
-            "\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF"
-            "\xD0\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\xDD\xDE\xDF"
-            "\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF"
-            "\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF",
-            "AAAAAAAeCEEEEIIII" "DNOOOOO OUUUUYThss" "aaaaaaaeceeeeiiii" "dnooooo ouuuuythy",
+            "\xc0\xc1\xc2\xc3\xc4\xc5\xc6\xc7\xc8\xc9\xca\xcb\xcc\xcd\xce\xcf"
+            "\xd0\xd1\xd2\xd3\xd4\xd5\xd6\xd7\xd8\xd9\xda\xdb\xdc\xdd\xde\xdf"
+            "\xe0\xe1\xe2\xe3\xe4\xe5\xe6\xe7\xe8\xe9\xea\xeb\xec\xed\xee\xef"
+            "\xf0\xf1\xf2\xf3\xf4\xf5\xf6\xf7\xf8\xf9\xfa\xfb\xfc\xfd\xfe\xff",
+            "AAAAAAAeCEEEEIIIIDNOOOOO OUUUUYThssaaaaaaaeceeeeiiiidnooooo ouuuuythy",
         ),
         ("abcABC", "abcABC"),
         ("", ""),
@@ -225,37 +227,13 @@ def test_escape(case, expected):
         ("abc", "abc"),
         ("", ""),
         (None, ""),
-    ],
-)
-def test_escape_reg_exp(case, expected):
-    assert _.escape_reg_exp(case) == expected
-
-
-@pytest.mark.skipif(sys.version_info < (3, 7), reason="requires python3.7 or higher")
-@parametrize(
-    "case,expected",
-    [  # noqa
         (
             "[pydash](http://pydash.readthedocs.org/)",
             "\\[pydash\\]\\(http://pydash\\.readthedocs\\.org/\\)",
         ),
     ],
 )
-def test_escape_reg_exp_gte_py37(case, expected):
-    assert _.escape_reg_exp(case) == expected
-
-
-@pytest.mark.skipif(sys.version_info >= (3, 7), reason="requires python3.6 or lower")
-@parametrize(
-    "case,expected",
-    [  # noqa
-        (
-            "[pydash](http://pydash.readthedocs.org/)",  # noqa
-            r"\[pydash\]\(http\:\/\/pydash\.readthedocs\.org\/\)",
-        ),
-    ],
-)
-def test_escape_reg_exp_lte_py36(case, expected):
+def test_escape_reg_exp(case, expected):
     assert _.escape_reg_exp(case) == expected
 
 
@@ -393,7 +371,10 @@ def test_join(case, expected):
         ("Σὲ γνωρίζω ἀπὸ τὴν κόψη", "σὲ-γνωρίζω-ἀπὸ-τὴν-κόψη"),
         ("แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช", "แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช"),
         ("いろはにほへど　ちりぬるを", "いろはにほへど-ちりぬるを"),
-        ("나는 유리를 먹을 수 있어요. 그래도 아프지 않아요", "나는-유리를-먹을-수-있어요-그래도-아프지-않아요"),
+        (
+            "나는 유리를 먹을 수 있어요. 그래도 아프지 않아요",
+            "나는-유리를-먹을-수-있어요-그래도-아프지-않아요",
+        ),
         ("J'peux manger d'la vitre, ça m'fa pas mal.", "jpeux-manger-dla-vitre-ca-mfa-pas-mal"),
         (
             "e peux manger du verre, ça ne me fait pas mal.",
@@ -788,7 +769,8 @@ def test_series_phrase_serial(case, expected):
     [
         ("Foo Bar", "foo-bar"),
         (" foo bar ", "foo-bar"),
-        ("Un éléphant à l'orée du bois", "un-elephant-a-l-oree-du-bois"),
+        ("Un éléphant à l'orée du bois", "un-elephant-a-loree-du-bois"),
+        ("shouldn't couldn't wouldn't", "shouldnt-couldnt-wouldnt"),
         ("", ""),
         (5, "5"),
         (None, ""),
@@ -815,7 +797,10 @@ def test_slugify(case, expected):
         ("Σὲ γνωρίζω ἀπὸ τὴν κόψη", "σὲ_γνωρίζω_ἀπὸ_τὴν_κόψη"),
         ("แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช", "แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช"),
         ("いろはにほへど　ちりぬるを", "いろはにほへど_ちりぬるを"),
-        ("나는 유리를 먹을 수 있어요. 그래도 아프지 않아요", "나는_유리를_먹을_수_있어요_그래도_아프지_않아요"),
+        (
+            "나는 유리를 먹을 수 있어요. 그래도 아프지 않아요",
+            "나는_유리를_먹을_수_있어요_그래도_아프지_않아요",
+        ),
         ("J'peux manger d'la vitre, ça m'fa pas mal.", "jpeux_manger_dla_vitre_ca_mfa_pas_mal"),
         (
             "e peux manger du verre, ça ne me fait pas mal.",
